@@ -3,4 +3,4 @@ class Hi:
         print("preparing to say hi...")
 
     def say_hi(self):
-        print("Hi!")
+        print("Hi you! ")
